var globals_func =
[
    [ "e", "globals_func.html", null ],
    [ "f", "globals_func_f.html", null ],
    [ "r", "globals_func_r.html", null ],
    [ "s", "globals_func_s.html", null ],
    [ "t", "globals_func_t.html", null ]
];